`js.foundation <http://github.com/ppinette/jsfoundation>`_
============================================================================

This package provides a `Fanstatic <http://fanstatic.org>`_ packaging of `Foundation <http://foundation.zurb.com>`_.

Information
===========

* Includes Foundation JS, CSS, SCSS, images, and Compass config file
* Only CSS and JS are served by Fanstatic. The rest are included for customization
* Foundation JS/CSS can be served separately or as a group
